@@ -19,8 +19,8 @@ class BaseLibrary(object):
     def __init__(self, show, season, episode, cache):
         self.cache = cache
         self.show = show
-        self.season = season
-        self.episode = episode
+        self.season = season.lstrip('0')
+        self.episode = episode.lstrip('0')
 
         self.log.info('Searching: {0}'.format(self.show))
         self.set_show_id()
@@ -155,8 +155,13 @@ class TvRage(BaseLibrary):
     url_base = 'http://services.tvrage.com/feeds/'
 
     def build_episode_url(self):
-        url_episode = 'full_show_info.php?sid='
-        return '{0}{1}{2}'.format(self.url_base, url_episode, self.show_id)
+        args = (
+            self.url_base,
+            self.show_id,
+            self.season,
+            self.episode
+        )
+        return '{0}episodeinfo.php?sid={1}&ep={2}x{3}'.format(*args)
 
     def build_id_url(self, quoted_show):
         url_series = 'search.php?show='
@@ -165,20 +170,15 @@ class TvRage(BaseLibrary):
     def get_episode_title_from_xml(self, xml):
         # In a single digit episode number add a zero
         if len(self.episode) == 1 and self.episode[:1] != '0':
-            self.episode = '0' + self.episode
+            self.episode = self.episode.zfill(2)
 
-        episode = None
-        for s in xml.find('Episodelist'):
-            if s.get('no') == self.season:
-                for e in s.findall('episode'):
-                    if e.find('seasonnum').text == self.episode:
-                        episode = e.find('title').text
-
-        if not episode:
+        try:
+            return xml.find('./episode/title').text
+        except AttributeError:
             args = (self.log.name, self.show, self.season, self.episode)
             raise errors.EpisodeNotFoundException(*args)
 
-        return episode
+        return self.episode
 
     def get_show_id_from_xml(self, xml):
         for name in xml.findall('show'):
